# Data

**Author**: Nele Albers

**Date**: January 2025


This README-file is meant to give you an overview of the data underlying our analyses.

Authored by Nele Albers, Francisco S. Melo, Mark A. Neerincx, Olya Kudina, and Willem-Paul Brinkman.


### Types of information

Below we describe the types of information we provide in this repository.


#### Activity difficulty data

The folder "Activity_Difficulty_Data" provides the preprocessed activity difficulty ratings data. To reproduce the preprocessing, first download the file "ratings_data_anonym.csv" from this DOI: https://doi.org/10.4121/5198f299-9c7a-40f8-8206-c18df93ee2a0. Place the downloaded file in the "Activity_Difficulty_Data"-folder.


#### Data from previous studies without human feedback

The folder "Data_Previous_Studies" should store the effort scores from our two previous studies without the possibility of receiving human feedback:
   - The data from the first study needs to be downloaded from this DOI: https://doi.org/10.4121/21533055. Specifically, you need to download the file "conversational_sessions_anonym.xlsx" and save it as "_data_study_0_conversational_sessions_anonym.xlsx."
   - The data from the second study needs to be downloaded from this DOI: https://doi.org/10.4121/9c4d9c35-3330-4536-ab8d-d5bb237c277d. Specifically, you need to download the file "Step_5_Training_The_Model_Results/Data/sessionsdata_anonym.csv" and save it as "_data_study_1_sessionsdata_anonym.csv."


#### Anonymization code

We provide the code used to anonymize the data from our study. For example, the file "anonymize_sessiondata_human_inv.py" shows how we anonymized the data from the conversational sessions. Since we cannot provide the non-anonymized data, you cannot run these files yourself. For some of the preprocessing files, there is also a corresponding .txt-file with some log data. For example, the file "clean_and_anonymize_postquestionnaire_data_output.txt" provides log information for running the file "clean_and_anonymize_postquestionnaire_data.py."


#### Anonymized data from our study

We provide the anonymized data from our study. This includes:
   - Data from the prescreening questionnaire (e.g., stage of change for quitting smoking),
   - Data from people's Prolific profiles (e.g., age, gender),
   - Data from the conversational sessions (e.g., effort spent on activities),
   - Data from the post-questionnaire (e.g., weights for allocation principles), and
   - Data on people clicking on the reading confirmation links in the human feedback messages.
   
For each data file, there is a corresponding .xlsx-file explaining each column in the data file. For example, the file "sessionsdata_data_explanation.xlsx" explains the columns in the file "sessionsdata_anonym.csv."

Data from the different files can be linked using the anonymized participant identifier "rand_id."


### Explanation of files and folders

This directory contains the following files and folders:
   - Activity_Difficulty_Data:
      - Activity_Formulations_Competencies_Study_and_Mapping_to_Human_Inv_Activities.xlsx: Mapping between activity indices in our study and the activity difficulty ratings dataset.
	  - merge_data_difficulty_data_for_human_inv_study.py: Get the activity difficulty ratings for the activities used in our study.
	  - Merged_Data_Difficulty_Ratings_Activities.csv: Activity difficulty ratings for the activities used in our study.
   
   - Data_Previous_Studies:
      - This folder is initially empty. To reproduce our analyses, you need to download the two files with data from previous studies and save them in this folder as described earlier in this README-file.
	  
   - anonymize_sessiondata_human_inv.py: Anonymize the data from the conversational sessions.
   - clean_and_anonymize_feedback_reading_confirmation_data.py: Anonymize the data on people clicking on reading confirmation links in the feedback messages.
   - clean_and_anonymize_feedback_reading_data_output.txt: Output of running the file above.
   - clean_and_anonymize_postquestionnaire_data.py: Anonymize the post-questionnaire data.
   - clean_and_anonymize_postquestionnaire_data_output.txt: Output of running the file above.
   - clean_and_anonymize_prescreening_data_human_inv.py: Anonymize the prescreening data (prescreening questionnaire + Prolific profiles).
   - clean_and_anonymize_prescreening_data_human_inv_output.txt: Output of running the file above.
   - feedback_reading_confirmation_anonym.csv: Anonymized reading confirmation data.
   - feedback_reading_confirmation_data_explanation.xlsx: Explanation of the columns in the file above.
   - postquestionnaire_anonym.csv: Anonymized post-questionnaire data.
   - postquestionnaire_data_explanation.xlsx: Explanation of the columns in the file above.
   - prescreening_questionnaire_anonym.csv: Anonymized prescreening questionnaire data.
   - prescreening_questionnaire_data_explanation.xlsx: Explanation of the columns in the file above.
   - prolific_profile_anonym.csv: Anonymized Prolific profile data.
   - prolific_profile_data_explanation.xlsx: Explanation of the columns in the file above.
   - README.md/README.pdf: This Readme-file.
   - sessionsdata_anonym.csv: Anonymized data from the conversational sessions.
   - sessionsdata_data_explanation.xlsx: Explanation of the columns in the file above.
